@@ -7,6 +7,7 @@ __author__ = "David Rusk <drusk@uvic.ca>"
 import os
 import re
 import sys
+import traceback
 
 from astropy import units
 from astropy.coordinates import SkyCoord
@@ -34,7 +35,7 @@ OBS_LIST_PATTERN = "#\s+(?P<rawname>(?P<fk>%s)?(?P<expnum>\d{6,7})(?P<ftype>[ops
 STATIONARY_LIST_PATTERN = "(?P<rawname>(?P<fk>fk)?(?P<expnum>\d{6,7})(?P<ftype>[ops])).vetting"
 
 # Observation header keys
-MOPVERSION = "MOPversion"
+MOPVERSION = "MOP_VER"
 
 # NOTE: MJD_OBS_CENTER is actually MJD-OBS-CENTER in the .astrom files, but
 # dashes aren't valid as regex names so I use underscores
@@ -365,7 +366,7 @@ class BaseAstromWriter(object):
                 return tuple(header_vals)
 
             self._write_line("## MOPversion")
-            self._write_line("#  %s" % header[MOPVERSION])
+            self._write_line("#  %s" % header.get(MOPVERSION, 1.20))
             self._write_line("## MJD-OBS-CENTER  EXPTIME THRES FWHM  MAXCOUNT CRVAL1     CRVAL2     EXPNUM")
             self._write_line("# %s%8.2f%6.2f%6.2f%9.1f%11.5f%11.5f%9d" % get_header_vals(
                 [MJD_OBS_CENTER, EXPTIME, THRES, FWHM, MAXCOUNT, CRVAL1, CRVAL2, EXPNUM]))
@@ -1035,10 +1036,11 @@ class Observation(object):
         return observation
 
     def __init__(self, expnum, ftype, ccdnum, fk=None, image_uri=None):
+        self._ccdnum = None
         self.expnum = expnum
         self.fk = fk is not None and fk or ""
         self._header = None
-        self.ccdnum = ccdnum is not None and str(ccdnum) or None
+        self.ccdnum = ccdnum
         self.ftype = ftype is not None and str(ftype) or None
         self.rawname = "{}{}{}{}".format(self.fk, self.expnum, ftype is not None and ftype or "",
                                          ccdnum is not None and str(ccdnum).zfill(2) or "")
@@ -1046,6 +1048,14 @@ class Observation(object):
         if image_uri is None:
             self.image_uri = self.get_image_uri()
 
+    @property
+    def ccdnum(self):
+        return self._ccdnum
+
+    @ccdnum.setter
+    def ccdnum(self, value):
+        self._ccdnum = value is not None and str(value) or None
+
     def __repr__(self):
         return "<Observation rawname=%s>" % self.rawname
 
@@ -1054,7 +1064,7 @@ class Observation(object):
 
     # TODO Remove get_image_uri from here, use the storage methods.
     def get_image_uri(self):
-        if self.ftype == 'p' and (self.fk is None or self.fk == ''):
+        if self.ftype == 'p' and len(f'{self.expnum}') < 8 and (self.fk is None or self.fk == ''):
             return storage.dbimages_uri(self.expnum)
 
         return storage.dbimages_uri(self.expnum,
@@ -1109,7 +1119,6 @@ class Observation(object):
         header = self.header
         if isinstance(header, list):
             extno = self.ccdnum - 1
-            print("Reading extension {} looking for header of CCD {}".format(extno, self.ccdnum))
             header = header[extno]
         mpc_date = header.get('MJD_OBS_CENTER', None)
         if mpc_date is None and 'MJD-OBS' in header:
