@@ -1,30 +1,29 @@
-from math import sqrt
-import operator
 import math
-import sys
+import operator
 import os
 import string
+import sys
+from math import sqrt
 
-from matplotlib.patches import Rectangle
-from matplotlib.patches import Ellipse
-from matplotlib import rcParams
-import numpy as np
-from matplotlib.pyplot import figure, savefig
-from astropy.io import votable
-import ephem
-import Polygon
 import Polygon.IO
+import ephem
+import numpy as np
+from astropy.io import votable
+from matplotlib import rcParams
+from matplotlib.patches import Ellipse
+from matplotlib.patches import Rectangle
+from matplotlib.pyplot import figure, savefig
 
+from ossos import mpc
+from ossos import orbfit
+from ossos import storage
+from . import megacam
 from . import mpcread
 from . import usnoB1
-from . import megacam
-from ossos import storage
-from ossos import orbfit
-from ossos import mpc
-
 
 USER = '/Users/michele/'
 
+
 def plot_line(axes, fname, ltype):
     """plot the ecliptic plane line on the given axes."""
     x = np.genfromtxt(fname, unpack=True)
@@ -40,15 +39,14 @@ L7MODEL = 'vos:OSSOS/CFEPS/L7SyntheticModel-v09.txt'
 REAL_KBO_AST_DIR = USER + 'Dropbox/OSSOS/measure3/ossin/'
 
 PLOT_FIELD_EPOCH = 'Feb15'  # Oct14.00 ==> '0' days since the New Moon on Oct14
-#TODO the .00 is appended when this variable is used as a keyword that needs that .00 this is bad.
+# TODO the .00 is appended when this variable is used as a keyword that needs that .00 this is bad.
 DISCOVERY_NEW_MOON = 'Nov13'  # this is the date that the RA/DEC in blocks corresponds to.
 
-
 PLOT_USNO_STARS = False
 PLOT_MEGACAM_ARCHIVE_FIELDS = True
 PLOT_SYNTHETIC_KBOS = True
 PLOT_SYNTHETIC_KBO_TRAILS = False
-PLOT_REAL_KBOS = False and os.access(REAL_KBO_AST_DIR,os.F_OK)
+PLOT_REAL_KBOS = False and os.access(REAL_KBO_AST_DIR, os.F_OK)
 PLOT_FIELD_LAYOUT = True
 
 PLOT_MPCORB = False and os.access(MPCORB_FILE, os.F_OK)
@@ -136,13 +134,13 @@ NAME                |RA         |DEC        |EPOCH |POINT|
 
 # spring13
 # blocks = {#'13AE': {"RA": "14:15:28.89", "DEC": "-12:32:28.4"},  # E+0+0: image 1616681, ccd21 on April 9
-#'13AO': {"RA": "15:58:01.35", "DEC": "-12:19:54.2"},  # O+0+0: image 1625346, ccd21 on May 8
-#'14AN': {'RA': "15:30:00.00", "DEC": "-11:00:00.0"},
-#'14AM': {'RA': "15:30:00.00", "DEC": "-12:20:00.0"},
-#'14AS': {'RA': "15:12:00.00", "DEC": "-17:40:00.0"}}
+# '13AO': {"RA": "15:58:01.35", "DEC": "-12:19:54.2"},  # O+0+0: image 1625346, ccd21 on May 8
+# '14AN': {'RA': "15:30:00.00", "DEC": "-11:00:00.0"},
+# '14AM': {'RA': "15:30:00.00", "DEC": "-12:20:00.0"},
+# '14AS': {'RA': "15:12:00.00", "DEC": "-17:40:00.0"}}
 
 
-#fall13
+# fall13
 blocks = {'13BL': {'RA': "00:54:00.00", "DEC": "+03:50:00.00"},  # ,
           '13AE': {"RA": "14:15:28.89", "DEC": "-12:32:28.4"},  # E+0+0: image 1616681, ccd21 on April 9
           '13AO': {"RA": "15:58:01.35", "DEC": "-12:19:54.2"},  # O+0+0: image 1625346, ccd21 on May 8
@@ -153,7 +151,7 @@ blocks = {'13BL': {'RA': "00:54:00.00", "DEC": "+03:50:00.00"},  # ,
 ## this position is derived from the +0+0 field for 13B observed on November 1st 2013
 blocks = {'14BH': {'RA': "01:28:32.32", "DEC": "+12:51:06.10"}}
 
-#fall 2015
+# fall 2015
 # blocks = {'15BD': {'RA': "03:15:00.00", "DEC": "+16:30:00.00"}}
 
 # spring14
@@ -161,30 +159,30 @@ blocks = {'14BH': {'RA': "01:28:32.32", "DEC": "+12:51:06.10"}}
 # blocks = {'15AP': {'RA': "13:30:00", "DEC": "-07:00:00"}}
 
 newMoons = {
-#    'Feb13': "2013/02/10 10:00:00",
-#    'Mar13': "2013/03/11 10:00:00",
-#    'Apr13': "2013/04/10 10:00:00",
-#    'May13': "2013/05/09 10:00:00",
-#    'Jun13': "2013/06/08 10:00:00",
-#    'Jul13': "2013/07/08 10:00:00",
-#    'Aug13': "2013/08/06 10:00:00",
-#    'Sep13': '2013/09/05 10:00:00',
-#    'Oct13': '2013/10/04 10:00:00',
-'Nov13': '2013/11/03 10:00:00',
-#    'Dec13': '2013/12/02 10:00:00',
-#    'Jan14': '2014/01/01 10:00:00',
-#    'Feb14': '2014/01/31 10:00:00',
-#    'Mar14': '2014/03/28 10:00:00',
-# 'Apr14': '2014/04/01 10:00:00',
-#    'May14': '2014/05/28 10:00:00',
-#    'Jun14': '2014/06/26 10:00:00',
-#    'Jul14': '2014/07/26 10:00:00',
-#    'Aug14': "2014/08/25 10:00:00",
-#    'Sep14': '2014/09/24 10:00:00',
-#     'Oct14': '2014/10/23 10:00:00',
-'Nov14': '2014/11/22 10:00:00',
-#    'Dec14': '2014/12/22 10:00:00',
-#    'Jan15': '2015/01/20 10:00:00',
+    #    'Feb13': "2013/02/10 10:00:00",
+    #    'Mar13': "2013/03/11 10:00:00",
+    #    'Apr13': "2013/04/10 10:00:00",
+    #    'May13': "2013/05/09 10:00:00",
+    #    'Jun13': "2013/06/08 10:00:00",
+    #    'Jul13': "2013/07/08 10:00:00",
+    #    'Aug13': "2013/08/06 10:00:00",
+    #    'Sep13': '2013/09/05 10:00:00',
+    #    'Oct13': '2013/10/04 10:00:00',
+    'Nov13': '2013/11/03 10:00:00',
+    #    'Dec13': '2013/12/02 10:00:00',
+    #    'Jan14': '2014/01/01 10:00:00',
+    #    'Feb14': '2014/01/31 10:00:00',
+    #    'Mar14': '2014/03/28 10:00:00',
+    # 'Apr14': '2014/04/01 10:00:00',
+    #    'May14': '2014/05/28 10:00:00',
+    #    'Jun14': '2014/06/26 10:00:00',
+    #    'Jul14': '2014/07/26 10:00:00',
+    #    'Aug14': "2014/08/25 10:00:00",
+    #    'Sep14': '2014/09/24 10:00:00',
+    #     'Oct14': '2014/10/23 10:00:00',
+    'Nov14': '2014/11/22 10:00:00',
+    #    'Dec14': '2014/12/22 10:00:00',
+    #    'Jan15': '2015/01/20 10:00:00',
     'Feb15': '2015/02/18 10:00:00',
     'Mar15': '2015/03/19 10:00:00',
     # 'Apr15': '2015/04/18 10:00:00',
@@ -212,8 +210,6 @@ newMoons = {
     # 'Feb17': '2017/02/01 10:00:00',
 }
 
-
-
 xgrid = {'2014': [-3, -2, -1, 0, 1, 2, 3],
          '2014r': [-3.5, -2.5, -1.5, -0.5, 0.5, 1.5, 2.5, 3.5],
          'astr': [1, 2, 3, 4]}
@@ -335,16 +331,16 @@ ras = np.array(ras)
 decs = np.array(decs)
 ra_cen = math.degrees(ras.mean())
 dec_cen = math.degrees(decs.mean())
-#ra_cen = 15.0
-#dec_cen = 5.0
-#width = 245 - 205
-#height = -8 + 25
-#ra_cen = 180.0
-#dec_cen = 0.0
-#width = 360
-#height = 70
-#ra_cen = 45.0
-#dec_cen = 17.5
+# ra_cen = 15.0
+# dec_cen = 5.0
+# width = 245 - 205
+# height = -8 + 25
+# ra_cen = 180.0
+# dec_cen = 0.0
+# width = 360
+# height = 70
+# ra_cen = 45.0
+# dec_cen = 17.5
 width = 10
 height = 10
 
@@ -352,21 +348,18 @@ height = 10
 fig = figure()
 ax = fig.add_subplot(111)
 
-
-ax.set_xlim(ra_cen+width/2.0, ra_cen-width/2.0)
-ax.set_ylim(dec_cen - height/2.0, dec_cen + height/2.0)
-#ax.set_ylim(-30,30)
+ax.set_xlim(ra_cen + width / 2.0, ra_cen - width / 2.0)
+ax.set_ylim(dec_cen - height / 2.0, dec_cen + height / 2.0)
+# ax.set_ylim(-30,30)
 ax.set_xlabel('RA (deg)')
 ax.set_ylabel('DE (deg)')
 
 ax.grid()
 
-
 ## plot the galactic plane line ..
 plot_line(ax, 'eplane.radec', 'b-')
 plot_line(ax, 'gplane.radec', 'g-')
 
-
 # Plot the invariable plane: values from DE405, table 5, Souami and Souchay 2012
 # http://www.aanda.org/articles/aa/pdf/2012/07/aa19011-12.pdf
 # Ecliptic J2000
@@ -381,8 +374,6 @@ for n in range(1, 360):
     # print n, ec.lat, ec.lon, eq.ra, eq.dec, math.degrees(eq.ra), math.degrees(eq.dec)
 ax.plot([math.degrees(eq.ra) for eq in invar], [math.degrees(eq.dec) for eq in invar], 'k-')
 
-
-
 ## build a list of Synthetic KBOs that will be in the discovery fields.
 print("LOADING SYNTHETIC MODEL KBOS FROM: {}".format(L7MODEL))
 ra = []
@@ -470,7 +461,6 @@ for month in seps:
     seps[month]['dra'] /= float(len(kbos))
     seps[month]['ddec'] /= float(len(kbos))
 
-
 sorted_epochs = sorted(iter(dates.items()), key=operator.itemgetter(1))
 
 print("CREATING ET XML FILES USING BASE POINTING AND NOMINAL MOTION RATES")
@@ -488,13 +478,13 @@ for idx in range(len(ras)):
         sdate = "%4s-%2s-%2s %2s:%2s:%2s" % (
             tdate[0], zf(tdate[1], 2), zf(tdate[2], 2), zf(tdate[3], 2), zf(tdate[4], 2), zf(int(tdate[5]), 2))
         f.write('%19s|%11s|%11s|\n' % (sdate, ephem.hours(ra), ephem.degrees(dec)))
-        if epoch == PLOT_FIELD_EPOCH+".00" and PLOT_FIELD_LAYOUT:
+        if epoch == PLOT_FIELD_EPOCH + ".00" and PLOT_FIELD_LAYOUT:
             ax.add_artist(Rectangle(xy=(math.degrees(ra) - dimen / 2.0, math.degrees(dec) - dimen / 2.0),
                                     height=camera_dimen,
                                     width=camera_dimen,
                                     edgecolor='b',
                                     lw=0.5, fill=True, alpha=0.3))
-            if LABEL_FIELDS :
+            if LABEL_FIELDS:
                 ax.text(math.degrees(ra), math.degrees(dec),
                         name,
                         horizontalalignment='center',
@@ -502,33 +492,32 @@ for idx in range(len(ras)):
                         zorder=10,
                         fontdict={'size': 4, 'color': 'darkblue'})
 
-
     f.write("""]]</CSV></DATA>\n</TABLE>\n</ASTRO>\n""")
     f.close()
 
-
 if PLOT_USNO_STARS:
     print("PLOTTING LOCATIONS NEARBY BRIGHT USNO B1 STARS")
-    for ra in range(int(ra_cen - width/2.0),int(ra_cen + width/2.), 10):
-        for dec in range(int(dec_cen - height/2.0),int(dec_cen + height/2.), 10):
+    for ra in range(int(ra_cen - width / 2.0), int(ra_cen + width / 2.), 10):
+        for dec in range(int(dec_cen - height / 2.0), int(dec_cen + height / 2.), 10):
             file_name = USER + "new_usno/usno{:5.2f}{:5.2f}.xml".format(ra, dec).replace(" ", "")
             print(file_name)
-            file_name = file_name.replace(" ","")
-	    if not os.access(file_name, os.R_OK):
+            file_name = file_name.replace(" ", "")
+            if not os.access(file_name, os.R_OK):
                 usno = usnoB1.TAPQuery(ra, dec, 10.0, 10.0)
-		fobj=open(file_name,'w')
-	        fobj.write(usno.read())
+                fobj = open(file_name, 'w')
+                fobj.write(usno.read())
                 fobj.close()
             try:
-               t = votable.parse(open(file_name,'r')).get_first_table()
+                t = votable.parse(open(file_name, 'r')).get_first_table()
             except:
-               print("No USNO stars found for: {} {}\n".format(ra,dec))
-               continue
-	    select = t.array['Bmag'] < 9.3
+                print("No USNO stars found for: {} {}\n".format(ra, dec))
+                continue
+            select = t.array['Bmag'] < 9.3
             Rmag = t.array['Bmag'][select]
             min_mag = max(Rmag.min(), 11)
             scale = 0.5 * 10 ** ((min_mag - Rmag) / 2.5)
-            ax.scatter(t.array['RAJ2000'][select], t.array['DEJ2000'][select], s=scale, marker='o', facecolor='y', alpha=0.3, edgecolor='',
+            ax.scatter(t.array['RAJ2000'][select], t.array['DEJ2000'][select], s=scale, marker='o', facecolor='y',
+                       alpha=0.3, edgecolor='',
                        zorder=-10)
 
     for planet in [ephem.Mars(), ephem.Jupiter(), ephem.Saturn(), ephem.Uranus(), ephem.Neptune()]:
@@ -538,18 +527,18 @@ if PLOT_USNO_STARS:
                    s=40,
                    facecolor='r',
                    edgecolor='g', )
-        if LABEL_PLANETS :
+        if LABEL_PLANETS:
             ax.text(math.degrees(planet.ra), math.degrees(planet.dec),
-                planet.name,
-                horizontalalignment='center',
-                fontdict={'size': 6,
-                          'color': 'darkred'})
+                    planet.name,
+                    horizontalalignment='center',
+                    fontdict={'size': 6,
+                              'color': 'darkred'})
 
 if PLOT_MEGACAM_ARCHIVE_FIELDS:
     print("PLOTTING FOOTPRINTS NEARBY ARCHIVAL MEGAPRIME IMAGES.")
 
-    for qra in range(int(ra_cen - width/2.0),int(ra_cen + width/2.), 60):
-        for qdec in range(int(dec_cen - height/2.0),int(dec_cen + height/2.), 30):
+    for qra in range(int(ra_cen - width / 2.0), int(ra_cen + width / 2.), 60):
+        for qdec in range(int(dec_cen - height / 2.0), int(dec_cen + height / 2.), 30):
             filename = USER + "megacam{:+6.2f}{:+6.2f}.xml".format(qra, qdec)
             if not os.access(filename, os.R_OK):
                 data = megacam.TAPQuery(qra, qdec, 60.0, 30.0).read()
@@ -587,29 +576,28 @@ if PLOT_MPCORB:
                    facecolor='g',
                    edgecolor='g', alpha=0.3)
 
-
 if PLOT_REAL_KBOS:
     reader = mpc.MPCReader()
     print("PLOTTING LOCATIONS OF OSSOS KBOs (using directory {})".format(REAL_KBO_AST_DIR))
     for ast in os.listdir(REAL_KBO_AST_DIR):
-        obs = reader.read(REAL_KBO_AST_DIR+ast)
+        obs = reader.read(REAL_KBO_AST_DIR + ast)
         try:
-           kbo = orbfit.Orbfit(obs)
+            kbo = orbfit.Orbfit(obs)
         except:
-           continue
+            continue
         kbo.predict(ephem.julian_date(ephem.date(plot_date)))
-        #if not field_polygon.isInside(float(kbo.coordinate.ra.degrees), float(kbo.coordinate.dec.degrees)):
+        # if not field_polygon.isInside(float(kbo.coordinate.ra.degrees), float(kbo.coordinate.dec.degrees)):
         #    continue
         if obs[0].mag < 23.6:
             c = 'b'
             if LABEL_FIELDS:
                 ax.text(kbo.coordinate.ra.degree,
-                    kbo.coordinate.dec.degree,
-                    ast.split('.')[0],
-                    horizontalalignment='center',
-                    verticalalignment='baseline',
-                    fontdict={'size': 6,
-                              'color': 'darkred'})
+                        kbo.coordinate.dec.degree,
+                        ast.split('.')[0],
+                        horizontalalignment='center',
+                        verticalalignment='baseline',
+                        fontdict={'size': 6,
+                                  'color': 'darkred'})
         else:
             c = 'g'
         ax.text(kbo.coordinate.ra.degree,
@@ -618,10 +606,10 @@ if PLOT_REAL_KBOS:
                 horizontalalignment='center',
                 verticalalignment='baseline',
                 fontdict={'size': 6,
-                'color': 'darkred'})
+                          'color': 'darkred'})
         ax.add_artist(Ellipse((kbo.coordinate.ra.degree, kbo.coordinate.dec.degree,),
-                              width=2.0*kbo.dra / 3600.0,
-                              height=2.0*kbo.ddec / 3600.0,
+                              width=2.0 * kbo.dra / 3600.0,
+                              height=2.0 * kbo.ddec / 3600.0,
                               angle=360 - (kbo.pa + 90),
                               edgecolor='none',
                               facecolor='k',
@@ -634,21 +622,23 @@ if PLOT_REAL_KBOS:
                    edgecolor=c,
                    alpha=0.5)
 
+new_tick_locations = np.array(list(range(360, 0, -30)))
+
 
-new_tick_locations = np.array(list(range(360,0,-30)))
 def tick_function(X):
     import calendar
-    month = ( X/30.0 + 8 ) % 12 + 1
-    return [ calendar.month_abbr[int(z)] for z in month ]
+    month = (X / 30.0 + 8) % 12 + 1
+    return [calendar.month_abbr[int(z)] for z in month]
+
+
 print(new_tick_locations)
 if False:
-    ax.set_xlim(360,0)
+    ax.set_xlim(360, 0)
     ax2 = ax.twiny()
     ax2.set_xticks(new_tick_locations)
     ax2.set_xticklabels(tick_function(new_tick_locations))
     ax2.set_xlabel("Opp. Month")
-    ax2.set_xlim(360,0)
-
+    ax2.set_xlim(360, 0)
 
 print("SAVING FILE")
 savefig('layout.pdf')
